@@ -50,9 +50,10 @@ if not build:
 
 sys.stdout.write("python %s (%s bit) using greenlet %s from %s\n" %
                  (sys.version.split()[0], bits(), greenlet.__version__, greenlet.__file__))
+sys.stdout.flush()
 
 
 # -- run tests
 from tests import test_collector
-suite = test_collector()
-unittest.TextTestRunner(verbosity=verbosity).run(suite)
+if unittest.TextTestRunner(verbosity=verbosity).run(test_collector()).failures:
+    sys.exit(1)
